(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     25109,        903]*)
(*NotebookOutlinePosition[     32318,       1114]*)
(*  CellTagsIndexPosition[     30607,       1063]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["SetFaceAndFont Palette", "IndexSection",
  CellTags->"MasterIndexHeading"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["CopyAsInputFormK",
    FontWeight->"Bold"],
  " button, copies the selected text in Input format, with formatting \
removed, see ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"CopyAsInputFormK button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["Peel",
    FontWeight->"Bold"],
  " button peels of brackets and quotation marks around the selected text, \
converts single cells to Text style and perform a number of other actions \
depending on the selection, see  ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Peel button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["Search",
    FontWeight->"Bold"],
  " button searches for information in the ",
  ButtonBox["online Mathematica help",
    ButtonData:>{
      URL[ "http://documents.wolfram.com/mathematica/book/"], None},
    ButtonStyle->"Hyperlink"],
  " using words in the selection ,  see ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Search button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["MG",
    FontWeight->"Bold"],
  " button searches in the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " forums (especially ",
  ButtonBox["MathGroup",
    ButtonData:>{
      URL[ "http://forums.wolfram.com/mathgroup/"], None},
    ButtonStyle->"Hyperlink"],
  ") for information using words in the selection ,  see ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"MG button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["Web",
    FontWeight->"Bold"],
  " button make an unrestricted Google search using words in the selection ,  \
see ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Web button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["StyleRemove",
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  " button ",
  " removes Style formatting of the selection, in a way similar to the ",
  StyleBox["\"Remove Options...\" ",
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  "menu item",
  ", see ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"StyleRemove button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["GetFontOptions",
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  " button reads the font options ",
  StyleBox["FontColor",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  ", ",
  StyleBox["FontFamily",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  ", ",
  StyleBox["FontProperties",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  ", ",
  StyleBox["FontSize",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  ", ",
  StyleBox["FontSlant",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  ", ",
  StyleBox["FontTracking",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  ", ",
  StyleBox["FontVariations",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  ", ",
  StyleBox["FontWeight",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  " and ",
  StyleBox["Background",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  " into the variable ",
  StyleBox["$FontPaintOptions",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  " from the selection. Together with the ",
  StyleBox[ButtonBox["PaintFontOptions button",
    ButtonData:>{"PaintFontOptions button"},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  " , these buttons are thus analogous to the Format Painter feature in \
Microsoft Word. See ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"GetFontOptions button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["PaintFontOptions",
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  " button sets the font options ",
  StyleBox["FontColor",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  ", ",
  StyleBox["FontFamily",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  ", ",
  StyleBox["FontProperties",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  ", ",
  StyleBox["FontSize",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  ", ",
  StyleBox["FontSlant",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  ", ",
  StyleBox["FontTracking",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  ", ",
  StyleBox["FontVariations",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  ", ",
  StyleBox["FontWeight",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  " and ",
  StyleBox["Background",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  "  for the selection from the variable ",
  StyleBox["$FontPaintOptions",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  ". Together with the ",
  StyleBox[ButtonBox["GetFontOptions button",
    ButtonData:>{"GetFontOptions button"},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  " , these buttons are thus analogous to the Format Painter feature in \
Microsoft Word. See ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"PaintFontOptions button"],

Cell[TextData[{
  "SetFaceAndFont2 Palette,  ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"SetFaceAndFont"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["*\[Rule]_",
    FontWeight->"Bold"],
  " button converts \"*\"signs to spaces. Using the \"",
  StyleBox["CopyAsInputFormK", "TI",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  StyleBox["\"", "TI",
    FontFamily->"Times",
    FontSlant->"Plain"],
  " button sometimes introduces \"*\" signs. This is not always wanted, and \
then this button can be used to convert back. The combinations \"",
  StyleBox["(*",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  "\", \"",
  StyleBox["*)",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  "\", \"",
  StyleBox["*^",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  "\", \"",
  StyleBox["**",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  "\" and \"",
  StyleBox["*=",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  "\" are not affected. See  ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"*\[Rule]_ button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["\[SelectionPlaceholder], \[SelectionPlaceholder]",
    FontWeight->"Bold"],
  "  button pastes a copy of the selection after the selection, with a comma \
in between. If whole cells are chosen, new cells are inserted, without \
commas. See ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"o, o button"],

Cell[TextData[{
  StyleBox["Duplicate button: The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["\[SelectionPlaceholder], \[SelectionPlaceholder]",
    FontWeight->"Bold"],
  "  button pastes a copy of the selection after the selection, with a comma \
in between. If whole cells are chosen, new cells are inserted, without \
commas. See ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Duplicate"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  "(* \[SelectionPlaceholder] *)",
  StyleBox[" ",
    FontWeight->"Bold"],
  " button wraps a comment parenthesis around the selection or inserts a \
comment parenthesis wrapping a placeholder. See ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"(* o *) button"],

Cell[TextData[{
  StyleBox["Comment button: The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  "(* \[SelectionPlaceholder] *)",
  StyleBox[" ",
    FontWeight->"Bold"],
  " button wraps a comment parenthesis around the selection or inserts a \
comment parenthesis wrapping a placeholder. See ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Comments"],

Cell[TextData[{
  StyleBox["Comment button: The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  "(* \[SelectionPlaceholder] *)",
  StyleBox[" ",
    FontWeight->"Bold"],
  " button wraps a comment parenthesis around the selection or inserts a \
comment parenthesis wrapping a placeholder. See ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"(* ... *)"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["Plain",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  " button turns the options FontSlant, FontWeight and Underline to \"",
  StyleBox["Plain",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  "\", \"",
  StyleBox["Plain",
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  "\" and \"",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  "\", see ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Plain"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["B",
    FontWeight->"Bold"],
  " (bold) button turns the option FontWeight to \"",
  StyleBox["Bold",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  "\",  see ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"B (bold)"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["I",
    FontSlant->"Italic"],
  " (Italic) button turns the option FontSlant to \"",
  StyleBox["Italic",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  "\",  see  ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"I (Italics)"],

Cell[TextData[{
  "The ",
  StyleBox["U",
    FontVariations->{"Underline"->True}],
  " (underline) button turns the option Underline to \"",
  StyleBox["Yrue",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  "\",  see  ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"U (underline)"],

Cell[TextData[{
  "The (\[SelectionPlaceholder]) button wraps a parenthesis around the \
selection or inserts a parenthesis wrapping a placeholder. See ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"(o) button"],

Cell[TextData[{
  "Parenthesis button:The (\[SelectionPlaceholder]) button wraps a \
parenthesis around the selection or inserts a parenthesis wrapping a \
placeholder. See ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Parentheses"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["{\[SelectionPlaceholder]}",
    FontWeight->"Bold"],
  " button wraps curly braces around the selection or inserts curly braces \
wrapping a placeholder. See ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"{o} button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["[\[SelectionPlaceholder]]",
    FontWeight->"Bold"],
  " button wraps square brackets around the selection or inserts square \
brackets wrapping a placeholder. See ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"[o] button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  "\[LeftDoubleBracket]\[SelectionPlaceholder]\[RightDoubleBracket] button \
wraps double brackets around the selection or inserts ",
  "double brackets",
  " wrapping a placeholder. See ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"[[o]] button"],

Cell[TextData[{
  StyleBox["Bracket buttons:\nThe ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["{\[SelectionPlaceholder]}",
    FontWeight->"Bold"],
  " button wraps curly braces around the selection or inserts curly braces \
wrapping a placeholder. ",
  StyleBox["\nThe ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["[\[SelectionPlaceholder]]",
    FontWeight->"Bold"],
  " button wraps square brackets around the selection or inserts square \
brackets wrapping a placeholder. ",
  StyleBox["\nThe ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  "\[LeftDoubleBracket]\[SelectionPlaceholder]\[RightDoubleBracket] button \
wraps double brackets around the selection or inserts double brackets \
wrapping a placeholder. \nSee ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Brackets"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["\"\[SelectionPlaceholder]\"",
    FontWeight->"Bold"],
  " button wraps quotes around the selection or inserts quotes wrapping a \
placeholder.  This button changes ",
  StyleBox["\"",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  " and ",
  StyleBox["\\",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  " inside the selected text to ",
  StyleBox["\\\"",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  " and ",
  StyleBox["\\\\",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  ", according to the way ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " handles strings within strings. See ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"\"o\" button"],

Cell[TextData[{
  StyleBox["Quote button: The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["\"\[SelectionPlaceholder]\"",
    FontWeight->"Bold"],
  " button wraps quotes around the selection or inserts quotes wrapping a \
placeholder.  This button changes ",
  StyleBox["\"",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  " and ",
  StyleBox["\\",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  " inside the selected text to ",
  StyleBox["\\\"",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  " and ",
  StyleBox["\\\\",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  ", according to the way ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " handles strings within strings. See ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Quotes"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  "9 fontsize button,  ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"9 fontsize button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  "10 fontsize button,  ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"10 fontsize button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  "12 fontsize button,  ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"12 fontsize button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  "14 fontsize button,  ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"14 fontsize button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  "16 fontsize button,  ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"16 fontsize button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  "18 fontsize button,  ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"18 fontsize button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  "24 fontsize button,  ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"24 fontsize button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  "36 fontsize button,  ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"36 fontsize button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  "72 fontsize button,  ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"72 fontsize button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["Courier",
    FontFamily->"Courier",
    FontSlant->"Plain"],
  " button,  ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Courier button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["Courier B",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  " button,  ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Courier B button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["Helvetica Plain",
    FontFamily->"Helvetica",
    FontSlant->"Plain"],
  " button,  ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Helvetica Plain button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  "Times Plain button,  ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Times Plain button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["Times Italic",
    FontFamily->"Times",
    FontSlant->"Italic"],
  " button,  ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Times Italic button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  "Black fontcolor button,  ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Black fontcolor button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["Red fontcolor",
    FontColor->RGBColor[1, 0, 0]],
  " button,  ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Red fontcolor button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["Green fontcolor",
    FontColor->RGBColor[0, 0.6, 0]],
  " button,  ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Green fontcolor button"],

Cell[TextData[{
  StyleBox["The ",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"Underline"->False}],
  StyleBox["Background color buttons",
    Background->RGBColor[1, 0.8, 1]],
  ",  ",
  ButtonBox["SetFaceAndFont",
    ButtonData:>{"SetFaceAndFont", "i:2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Background color buttons"]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 933}},
ScreenStyleEnvironment->"Brackets",
WindowSize->{568, 740},
WindowMargins->{{Automatic, 249}, {Automatic, 1}},
ShowCellTags->True,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "MasterIndexHeading"->{
    Cell[1754, 51, 80, 1, 56, "IndexSection",
      CellTags->"MasterIndexHeading"]},
  "CopyAsInputFormK button"->{
    Cell[1837, 54, 419, 13, 48, "Index",
      CellTags->"CopyAsInputFormK button"]},
  "Peel button"->{
    Cell[2259, 69, 496, 14, 65, "Index",
      CellTags->"Peel button"]},
  "Search button"->{
    Cell[2758, 85, 557, 17, 48, "Index",
      CellTags->"Search button"]},
  "MG button"->{
    Cell[3318, 104, 604, 20, 48, "Index",
      CellTags->"MG button"]},
  "Web button"->{
    Cell[3925, 126, 392, 13, 48, "Index",
      CellTags->"Web button"]},
  "StyleRemove button"->{
    Cell[4320, 141, 608, 21, 48, "Index",
      CellTags->"StyleRemove button"]},
  "GetFontOptions button"->{
    Cell[4931, 164, 1688, 63, 99, "Index",
      CellTags->"GetFontOptions button"]},
  "PaintFontOptions button"->{
    Cell[6622, 229, 1687, 63, 99, "Index",
      CellTags->"PaintFontOptions button"]},
  "SetFaceAndFont"->{
    Cell[8312, 294, 194, 6, 31, "Index",
      CellTags->"SetFaceAndFont"]},
  "\[RawStar]\[Rule]_ button"->{
    Cell[8509, 302, 1117, 40, 82, "Index",
      CellTags->"\[RawStar]\[Rule]_ button"]},
  "o, o button"->{
    Cell[9629, 344, 525, 14, 48, "Index",
      CellTags->"o, o button"]},
  "Duplicate"->{
    Cell[10157, 360, 541, 14, 65, "Index",
      CellTags->"Duplicate"]},
  "(\[RawStar] o \[RawStar]) button"->{
    Cell[10701, 376, 475, 14, 48, "Index",
      CellTags->"(\[RawStar] o \[RawStar]) button"]},
  "Comments"->{
    Cell[11179, 392, 485, 14, 48, "Index",
      CellTags->"Comments"]},
  "(\[RawStar] ... \[RawStar])"->{
    Cell[11667, 408, 486, 14, 48, "Index",
      CellTags->"(\[RawStar] ... \[RawStar])"]},
  "Plain"->{
    Cell[12156, 424, 800, 29, 48, "Index",
      CellTags->"Plain"]},
  "B (bold)"->{
    Cell[12959, 455, 448, 16, 31, "Index",
      CellTags->"B (bold)"]},
  "I (Italics)"->{
    Cell[13410, 473, 456, 16, 31, "Index",
      CellTags->"I (Italics)"]},
  "U (underline)"->{
    Cell[13869, 491, 374, 13, 31, "Index",
      CellTags->"U (underline)"]},
  "(o) button"->{
    Cell[14246, 506, 297, 7, 48, "Index",
      CellTags->"(o) button"]},
  "Parentheses"->{
    Cell[14546, 515, 319, 8, 48, "Index",
      CellTags->"Parentheses"]},
  "{o} button"->{
    Cell[14868, 525, 442, 13, 48, "Index",
      CellTags->"{o} button"]},
  "[o] button"->{
    Cell[15313, 540, 448, 13, 48, "Index",
      CellTags->"[o] button"]},
  "[[o]] button"->{
    Cell[15764, 555, 461, 13, 48, "Index",
      CellTags->"[[o]] button"]},
  "Brackets"->{
    Cell[16228, 570, 1037, 28, 133, "Index",
      CellTags->"Brackets"]},
  "\"o\" button"->{
    Cell[17268, 600, 912, 32, 65, "Index",
      CellTags->"\"o\" button"]},
  "Quotes"->{
    Cell[18183, 634, 920, 32, 65, "Index",
      CellTags->"Quotes"]},
  "9 fontsize button"->{
    Cell[19106, 668, 302, 10, 31, "Index",
      CellTags->"9 fontsize button"]},
  "10 fontsize button"->{
    Cell[19411, 680, 304, 10, 31, "Index",
      CellTags->"10 fontsize button"]},
  "12 fontsize button"->{
    Cell[19718, 692, 304, 10, 31, "Index",
      CellTags->"12 fontsize button"]},
  "14 fontsize button"->{
    Cell[20025, 704, 304, 10, 31, "Index",
      CellTags->"14 fontsize button"]},
  "16 fontsize button"->{
    Cell[20332, 716, 304, 10, 31, "Index",
      CellTags->"16 fontsize button"]},
  "18 fontsize button"->{
    Cell[20639, 728, 304, 10, 31, "Index",
      CellTags->"18 fontsize button"]},
  "24 fontsize button"->{
    Cell[20946, 740, 304, 10, 31, "Index",
      CellTags->"24 fontsize button"]},
  "36 fontsize button"->{
    Cell[21253, 752, 304, 10, 31, "Index",
      CellTags->"36 fontsize button"]},
  "72 fontsize button"->{
    Cell[21560, 764, 304, 10, 31, "Index",
      CellTags->"72 fontsize button"]},
  "Courier button"->{
    Cell[21867, 776, 363, 13, 31, "Index",
      CellTags->"Courier button"]},
  "Courier B button"->{
    Cell[22233, 791, 391, 14, 32, "Index",
      CellTags->"Courier B button"]},
  "Helvetica Plain button"->{
    Cell[22627, 807, 381, 13, 31, "Index",
      CellTags->"Helvetica Plain button"]},
  "Times Plain button"->{
    Cell[23011, 822, 304, 10, 31, "Index",
      CellTags->"Times Plain button"]},
  "Times Italic button"->{
    Cell[23318, 834, 372, 13, 31, "Index",
      CellTags->"Times Italic button"]},
  "Black fontcolor button"->{
    Cell[23693, 849, 312, 10, 31, "Index",
      CellTags->"Black fontcolor button"]},
  "Red fontcolor button"->{
    Cell[24008, 861, 358, 12, 31, "Index",
      CellTags->"Red fontcolor button"]},
  "Green fontcolor button"->{
    Cell[24369, 875, 364, 12, 31, "Index",
      CellTags->"Green fontcolor button"]},
  "Background color buttons"->{
    Cell[24736, 889, 369, 12, 31, "Index",
      CellTags->"Background color buttons"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"MasterIndexHeading", 25807, 921},
  {"CopyAsInputFormK button", 25924, 924},
  {"Peel button", 26029, 927},
  {"Search button", 26124, 930},
  {"MG button", 26217, 933},
  {"Web button", 26308, 936},
  {"StyleRemove button", 26408, 939},
  {"GetFontOptions button", 26519, 942},
  {"PaintFontOptions button", 26636, 945},
  {"SetFaceAndFont", 26746, 948},
  {"\[RawStar]\[Rule]_ button", 26856, 951},
  {"o, o button", 26965, 954},
  {"Duplicate", 27057, 957},
  {"(\[RawStar] o \[RawStar]) button", 27171, 960},
  {"Comments", 27284, 963},
  {"(\[RawStar] ... \[RawStar])", 27392, 966},
  {"Plain", 27497, 969},
  {"B (bold)", 27583, 972},
  {"I (Italics)", 27675, 975},
  {"U (underline)", 27772, 978},
  {"(o) button", 27868, 981},
  {"Parentheses", 27961, 984},
  {"{o} button", 28054, 987},
  {"[o] button", 28147, 990},
  {"[[o]] button", 28242, 993},
  {"Brackets", 28335, 996},
  {"\"o\" button", 28430, 999},
  {"Quotes", 28521, 1002},
  {"9 fontsize button", 28617, 1005},
  {"10 fontsize button", 28725, 1008},
  {"12 fontsize button", 28834, 1011},
  {"14 fontsize button", 28943, 1014},
  {"16 fontsize button", 29052, 1017},
  {"18 fontsize button", 29161, 1020},
  {"24 fontsize button", 29270, 1023},
  {"36 fontsize button", 29379, 1026},
  {"72 fontsize button", 29488, 1029},
  {"Courier button", 29593, 1032},
  {"Courier B button", 29696, 1035},
  {"Helvetica Plain button", 29807, 1038},
  {"Times Plain button", 29920, 1041},
  {"Times Italic button", 30030, 1044},
  {"Black fontcolor button", 30144, 1047},
  {"Red fontcolor button", 30259, 1050},
  {"Green fontcolor button", 30374, 1053},
  {"Background color buttons", 30493, 1056}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 80, 1, 56, "IndexSection",
  CellTags->"MasterIndexHeading"],
Cell[1837, 54, 419, 13, 48, "Index",
  CellTags->"CopyAsInputFormK button"],
Cell[2259, 69, 496, 14, 65, "Index",
  CellTags->"Peel button"],
Cell[2758, 85, 557, 17, 48, "Index",
  CellTags->"Search button"],
Cell[3318, 104, 604, 20, 48, "Index",
  CellTags->"MG button"],
Cell[3925, 126, 392, 13, 48, "Index",
  CellTags->"Web button"],
Cell[4320, 141, 608, 21, 48, "Index",
  CellTags->"StyleRemove button"],
Cell[4931, 164, 1688, 63, 99, "Index",
  CellTags->"GetFontOptions button"],
Cell[6622, 229, 1687, 63, 99, "Index",
  CellTags->"PaintFontOptions button"],
Cell[8312, 294, 194, 6, 31, "Index",
  CellTags->"SetFaceAndFont"],
Cell[8509, 302, 1117, 40, 82, "Index",
  CellTags->"\[RawStar]\[Rule]_ button"],
Cell[9629, 344, 525, 14, 48, "Index",
  CellTags->"o, o button"],
Cell[10157, 360, 541, 14, 65, "Index",
  CellTags->"Duplicate"],
Cell[10701, 376, 475, 14, 48, "Index",
  CellTags->"(\[RawStar] o \[RawStar]) button"],
Cell[11179, 392, 485, 14, 48, "Index",
  CellTags->"Comments"],
Cell[11667, 408, 486, 14, 48, "Index",
  CellTags->"(\[RawStar] ... \[RawStar])"],
Cell[12156, 424, 800, 29, 48, "Index",
  CellTags->"Plain"],
Cell[12959, 455, 448, 16, 31, "Index",
  CellTags->"B (bold)"],
Cell[13410, 473, 456, 16, 31, "Index",
  CellTags->"I (Italics)"],
Cell[13869, 491, 374, 13, 31, "Index",
  CellTags->"U (underline)"],
Cell[14246, 506, 297, 7, 48, "Index",
  CellTags->"(o) button"],
Cell[14546, 515, 319, 8, 48, "Index",
  CellTags->"Parentheses"],
Cell[14868, 525, 442, 13, 48, "Index",
  CellTags->"{o} button"],
Cell[15313, 540, 448, 13, 48, "Index",
  CellTags->"[o] button"],
Cell[15764, 555, 461, 13, 48, "Index",
  CellTags->"[[o]] button"],
Cell[16228, 570, 1037, 28, 133, "Index",
  CellTags->"Brackets"],
Cell[17268, 600, 912, 32, 65, "Index",
  CellTags->"\"o\" button"],
Cell[18183, 634, 920, 32, 65, "Index",
  CellTags->"Quotes"],
Cell[19106, 668, 302, 10, 31, "Index",
  CellTags->"9 fontsize button"],
Cell[19411, 680, 304, 10, 31, "Index",
  CellTags->"10 fontsize button"],
Cell[19718, 692, 304, 10, 31, "Index",
  CellTags->"12 fontsize button"],
Cell[20025, 704, 304, 10, 31, "Index",
  CellTags->"14 fontsize button"],
Cell[20332, 716, 304, 10, 31, "Index",
  CellTags->"16 fontsize button"],
Cell[20639, 728, 304, 10, 31, "Index",
  CellTags->"18 fontsize button"],
Cell[20946, 740, 304, 10, 31, "Index",
  CellTags->"24 fontsize button"],
Cell[21253, 752, 304, 10, 31, "Index",
  CellTags->"36 fontsize button"],
Cell[21560, 764, 304, 10, 31, "Index",
  CellTags->"72 fontsize button"],
Cell[21867, 776, 363, 13, 31, "Index",
  CellTags->"Courier button"],
Cell[22233, 791, 391, 14, 32, "Index",
  CellTags->"Courier B button"],
Cell[22627, 807, 381, 13, 31, "Index",
  CellTags->"Helvetica Plain button"],
Cell[23011, 822, 304, 10, 31, "Index",
  CellTags->"Times Plain button"],
Cell[23318, 834, 372, 13, 31, "Index",
  CellTags->"Times Italic button"],
Cell[23693, 849, 312, 10, 31, "Index",
  CellTags->"Black fontcolor button"],
Cell[24008, 861, 358, 12, 31, "Index",
  CellTags->"Red fontcolor button"],
Cell[24369, 875, 364, 12, 31, "Index",
  CellTags->"Green fontcolor button"],
Cell[24736, 889, 369, 12, 31, "Index",
  CellTags->"Background color buttons"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

